@@ -16,33 +16,25 @@
 # GNU General Public License for more details.
 #----------------------------------------------------------------------
 
-# "lset" forward compatibility routine from wiki.tcl.tk---"lset" is
-# used in these routines, and was new with Tcl version 8.4.
+# Declare the package by setting variable XCOps(module,matgen)
+set XCOps(module,matgen) 1
 
-if {[package vcompare [package provide Tcl] 8.4] < 0} {
-   proc tcl::K {a b} {return $a}
-   proc lset {listName index val} {
-      upvar $listName list
-      set list [lreplace [tcl::K $list [set list {}]] $index $index $val]
-   }
-}
-
-#----------------------------------------------------------------------
+#--------------------------------------------------------------------
 
 proc xcircuit::promptimportmatlab {} {
    .filelist.bbar.okay configure -command \
-      {matgen [.filelist.textent.txt get]; wm withdraw .filelist}
-   .filelist.listwin.win configure -data "ps"
+        {matgen [.filelist.textent.txt get]; wm withdraw .filelist}
+   .filelist.listwin.win configure -data "ps eps"
    .filelist.textent.title.field configure -text "Select file to import:"
    .filelist.textent.txt delete 0 end
    xcircuit::popupfilelist
 }
 
-#----------------------------------------------------------------------
+#--------------------------------------------------------------------
 
 proc matgen {argv} {
-global XCOps XCWinOps
 # PART 1: Command line parser_______________________________
+global XCOps XCWinOps
 # load-axes property is set
 set axes 1
 # set default scale factor
@@ -109,7 +101,7 @@ foreach file $filenames {
 	if [regexp {e?ps} $file matchresult] then {
 		# try to open $file
 		if [catch {open $file r} result] {
-			puts "Warning: $result"
+			puts stderr "Warning: $result"
 			return -1
 		} else {
 			set fp $result
@@ -133,7 +125,7 @@ foreach file $filenames {
 
 # exit with message when no source files are found 
 if [llength $validfiles]<1 {
-	puts "  *** No valid matlab .eps files found. Bye!";
+	puts stderr "  *** No valid matlab .eps files found. Bye!";
 	return -1
 }
 
@@ -142,7 +134,7 @@ foreach file $validfiles {
 	puts "Processing $file...";
 	# open each matlab eps file
 	if [catch {open $file r} result] {
-		puts "Warning: $result"
+		puts stderr "Warning: $result"
 		return -1
 	} else {
 		set fp $result
@@ -193,7 +185,7 @@ foreach file $validfiles {
 				# the polyline_vertices list contains all vertices
 				# --> {<undefined data> x1 y1 x2 y2 ... xn yn}
 			} else {
-				puts "Error in polyline regular expression. Exiting..."
+				puts stderr "Error in polyline regular expression. Exiting..."
 				return -1
 			}
 			# convert the arguments to the xcircuit coordinate format.
@@ -269,7 +261,7 @@ foreach file $validfiles {
 				# the polyline_vertices list contains all vertices
 				# --> {<undefined data> x1 y1 x2 y2 ... xn yn}
 			} else {
-				puts "Error in filled polyline regular expression. Exiting..."
+				puts stderr "Error in filled polyline regular expression. Exiting..."
 				return -1
 			}
 			# convert the arguments to the xcircuit coordinate format.
